@@ -32,10 +32,10 @@
 typedef struct {
   GConfClient *client;
   GladeXML *xml;
+  GnomeThumbnailFactory *thumb_factory;
 
   /* desktop */
   GHashTable *wp_hash;
-  GnomeThumbnailFactory *wp_thumbs;
   gboolean wp_update_gconf;
   GtkIconView *wp_view;
   GtkTreeModel *wp_model;
@@ -44,7 +44,7 @@ typedef struct {
   GtkWidget *wp_style_menu;
   GtkWidget *wp_color_menu;
   GtkWidget *wp_rem_button;
-  GtkWidget *wp_filesel;
+  GtkFileChooser *wp_filesel;
   GtkWidget *wp_image;
   GSList *wp_uris;
 
