@@ -23,9 +23,12 @@
 #ifndef GNOME_THEME_INFO_H
 #define GNOME_THEME_INFO_H
 
+#include <config.h>
+
 #include <glib.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
 
 typedef enum {
   GNOME_THEME_TYPE_METATHEME,
@@ -72,6 +75,7 @@ typedef struct _GnomeThemeCursorInfo GnomeThemeCursorInfo;
 struct _GnomeThemeCursorInfo {
   gchar *path;
   gchar *name;
+  gchar *readable_name;
   gint priority;
   GArray *sizes;
   GdkPixbuf *thumbnail;
@@ -92,6 +96,8 @@ struct _GnomeThemeMetaInfo
   gchar *metacity_theme_name;
   gchar *icon_theme_name;
   gchar *sound_theme_name;
+  gchar *cursor_theme_name;
+  gint cursor_size;
 
   gchar *application_font;
   gchar *desktop_font;
@@ -99,6 +105,18 @@ struct _GnomeThemeMetaInfo
   gchar *background_image;
 };
 
+enum {
+  COLOR_FG,
+  COLOR_BG,
+  COLOR_TEXT,
+  COLOR_BASE,
+  COLOR_SELECTED_FG,
+  COLOR_SELECTED_BG,
+  COLOR_TOOLTIP_FG,
+  COLOR_TOOLTIP_BG,
+  NUM_SYMBOLIC_COLORS
+};
+
 typedef void (* ThemeChangedCallback) (GnomeThemeType       type,
 				       gpointer             theme,
 				       GnomeThemeChangeType change_type,
@@ -149,4 +167,9 @@ void                gnome_theme_info_register_theme_change (ThemeChangedCallback
 gboolean            gnome_theme_is_writable                (const gpointer       theme,
 							    GnomeThemeType       type);
 
+gboolean            gnome_theme_color_scheme_parse         (const gchar         *scheme,
+							    GdkColor            *colors);
+gboolean            gnome_theme_color_scheme_equal         (const gchar         *s1,
+							    const gchar         *s2);
+
 #endif /* GNOME_THEME_INFO_H */
